package
Version:
v0.0.0-...-de6b16a
Opens a new window with list of versions in this module.
Published: Feb 7, 2021
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Token string `json:"token"`
TemplatePath string `json:"templatePath"`
Port float64 `json:"port"`
Debug bool `json:"debug"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.